[Pkg-mozext-commits] [firebug] 04/68: Issue 6282 (CSS panel fails on interpreting @page) http://code.google.com/p/fbug/issues/detail?id=6282

David Prévot taffit at moszumanska.debian.org
Mon Mar 31 22:45:49 UTC 2014


This is an automated email from the git hooks/post-receive script.

taffit pushed a commit to tag fbtest-1.11.4
in repository firebug.

commit 1920826f02698d258958da3d7ffd2aebe8ae0de6
Author: Sebastian Zartner <sebastianzartner at gmail.com>
Date:   Thu Feb 21 17:58:28 2013 +0100

    Issue 6282 (CSS panel fails on interpreting @page)
    http://code.google.com/p/fbug/issues/detail?id=6282
---
 extension/content/firebug/css/cssPanel.js | 12 +++++++-----
 1 file changed, 7 insertions(+), 5 deletions(-)

diff --git a/extension/content/firebug/css/cssPanel.js b/extension/content/firebug/css/cssPanel.js
index 90f70a0..9253ecd 100644
--- a/extension/content/firebug/css/cssPanel.js
+++ b/extension/content/firebug/css/cssPanel.js
@@ -442,12 +442,14 @@ Firebug.CSSStyleSheetPanel.prototype = Obj.extend(Firebug.Panel,
                 }
                 else if (rule instanceof window.CSSNameSpaceRule &&
                     !(rule instanceof window.MozCSSKeyframesRule ||
-                        rule instanceof window.MozCSSKeyframeRule))
+                        rule instanceof window.MozCSSKeyframeRule ||
+                        rule instanceof window.CSSPageRule))
                 {
-                    // Workaround for https://bugzilla.mozilla.org/show_bug.cgi?id=754772
-                    // MozCSSKeyframesRules and MozCSSKeyframeRules are recognized as
-                    // CSSNameSpaceRules, so explicitly check whether the rule is not a
-                    // MozCSSKeyframesRule or a MozCSSKeyframeRule
+
+                	// Workaround for https://bugzilla.mozilla.org/show_bug.cgi?id=754772
+                    // MozCSSKeyframesRules, MozCSSKeyframeRules and CSSPageRules are recognized
+                	// as CSSNameSpaceRules, so explicitly check whether the rule is not a
+                    // MozCSSKeyframesRule, a MozCSSKeyframeRule or a CSSPageRule
 
                     var reNamespace = /^@namespace ((.+) )?url\("(.*?)"\);$/;
                     var namespace = rule.cssText.match(reNamespace);

-- 
Alioth's /usr/local/bin/git-commit-notice on /srv/git.debian.org/git/pkg-mozext/firebug.git



More information about the Pkg-mozext-commits mailing list